@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 
 use Mojo::Util qw(camelize);
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub register {
   my ($self, $app, $conf) = @_;
@@ -153,7 +153,7 @@ sub register {
     'restify.current_id' => sub {
       my $c    = shift;
       my $name = $c->stash->{controller};
-      $name =~ s,^.*?\-,,;
+      $name =~ s,^.*\-,,;
       return $c->match->stack->[-1]->{"${name}_id"} // '';
     }
   );
@@ -582,7 +582,7 @@ The following options allow a I<collection> to be fine-tuned.
 =item collection_method_map
 
   $r->collection(
-    'invoives',
+    'invoices',
     {
       collection_method_map => {
         get  => 'list',
@@ -639,7 +639,7 @@ actions will be created.
 =item element_method_map
 
   $r->collection(
-    'invoives',
+    'invoices',
     {
       element_method_map  => {
         'delete' => 'delete',
